==> viha-5.15.tar.gz: viha-5.15/ryhma.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "ryhma";
$file = basename(__FILE__);

include "common.php";
include "ryhma-ok.php";

echo "
<html>
<head>
 <title>VIHA - Ryhmtiedot</title>
</head>
" . body_bgcolor() . "
<h1>" . ota_paivystys_nimi() . ", ryhmkohtaisten tietojen ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$paikka_id = get_nro_1('paikka_id');
$koordinaatit = get_txt('koordinaatit');
$ryhma_tila_id = get_nro_1('ryhma_tila_id');
$verkko_id = get_nro('verkko_id');
if ($verkko_id == "") { $verkko_id = ota_oletus_verkko_id(); }
$pri = get_nro('pri');
if ($pri == '') { $pri = 1000; }
$kutsu = get_txt('kutsu');
$puhelin = get_txt('puhelin');
$selite = get_txt('selite');
$tehtava = get_txt('tehtava');
$toiminta_alue = get_txt('toiminta_alue');
$toimintakanava = get_txt('toimintakanava');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = ryhma_add_ok($herja,s('alue'),
		      s('paivystys'),
		      $paikka_id,$ryhma_tila_id,$verkko_id,$kutsu);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           paikka_id = $paikka_id,
           koordinaatit = '$koordinaatit',
           ryhma_tila_id = $ryhma_tila_id,
           pri = $pri,
           verkko_id = $verkko_id,
           kutsu = '$kutsu',
           puhelin = '$puhelin',
           selite = '$selite',
           tehtava = '$tehtava',
           toiminta_alue = '$toiminta_alue',
           toimintakanava = '$toimintakanava',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot listty.\n";
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
    taktinen_loki("Listty ryhm $kutsu verkkoon "
		  . ota_verkko($verkko_id)
		  . ", sijainti "
		  . ota_paikka($paikka_id)
		  . ", tila "
		  . ota_ryhma_tila($ryhma_tila_id)
		  . ", selite $selite");
  }
  p_herja($ret,$herja);
}

if (($save != '') && saa_tehda("$file:save")) {
  $ret = ryhma_save_ok($herja,$id,s('alue'),
		       s('paivystys'),
		       $paikka_id,$ryhma_tila_id,$verkko_id,$kutsu);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET paikka_id=$paikka_id,
           koordinaatit='$koordinaatit',
           ryhma_tila_id=$ryhma_tila_id,
           pri=$pri,
           verkko_id=$verkko_id,
           kutsu='$kutsu',
           puhelin='$puhelin',
           selite='$selite',
           tehtava = '$tehtava',
           toiminta_alue = '$toiminta_alue',
           toimintakanava = '$toimintakanava',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
    taktinen_loki("Muutettu ryhm $kutsu, sijainti "
		  . ota_paikka($paikka_id)
		  . ", tila "
		  . ota_ryhma_tila($ryhma_tila_id));
  }
  p_herja($ret,$herja);
} # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = ryhma_remove_ok($herja,$id,true);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    taktinen_loki("Poistetaan ryhm " . ota_kutsu($id));
    $sql = "DELETE FROM $table WHERE id = $id";
    my_mysql_query ($sql,true,true);
    # silently update the man-hour table as well
    $sql =
      "UPDATE hlo_ajat
       SET variable_id = 1
       WHERE variable_id = $id AND hlo_ajat_tyyppi_id = 5";
    my_mysql_query ($sql,true,true);
    echo "<p>Tiedot poistettu.\n";
    $clear = "SISINEN";
  }
  p_herja($ret,$herja);
}

if ($clear != '') {
  $id = "0";
  $paikka_id = "1";
  $koordinaatit = '';
  $ryhma_tila_id = "1";
  $kutsu = '';
  $pri = "1000";
  $puhelin = '';
  $selite = '';
  $tehtava = '';
  $toiminta_alue = '';
  $toimintakanava = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = ryhma_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
}

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $paikka_id = $a['paikka_id'];
  $koordinaatit = $a['koordinaatit'];
  $ryhma_tila_id = $a['ryhma_tila_id'];
  $pri = $a['pri'];
  $verkko_id = $a['verkko_id'];
  $kutsu = $a['kutsu'];
  $puhelin = $a['puhelin'];
  $selite = $a['selite']; 
  $tehtava = $a['tehtava']; 
  $toiminta_alue = $a['toiminta_alue']; 
  $toimintakanava = $a['toimintakanava']; 
 }

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Sijainti:";
if ($readonly) {
  echo "<td>" . tab_col_id("paikka","",$paikka_id);
} else {
  echo "<td>\n";
  select_paikka_id($paikka_id);
}

echo "<tr><td>Koordinaatit:";
if ($readonly) {
  echo "<td>$koordinaatit\n";
} else {
  echo "<td><input type=\"text\" name=\"koordinaatit\" size=32 maxlength=32";
  echo " value=\"$koordinaatti\">\n";
  echo " Kartasta, muodossa X99\n";
}

echo "<tr><td>Tila:";
if ($readonly) {
  echo "<td>" . tab_col_id("ryhma_tila","",$ryhma_tila_id);
} else {
  echo "<td>\n";
  select_ryhma_tila_id($ryhma_tila_id);
}

echo "<tr><td>Prioriteetti:";
if ($readonly) {
  echo "<td>$pri\n";
} else {
  echo "<td><input type=\"text\" name=\"pri\" size=8 maxlength=8";
  echo " value=\"$pri\">\n";
  echo " Listauksia varten, pienempi prioriteetti listataan ensin.\n";
}

echo "<tr><td>Verkko:";
if ($readonly) {
  echo "<td>"
    . etsi_teksti("verkko_id", $verkko_id, "verkko", "id", "verkko") . "\n";
} else {
  echo "<td>\n";
  tee_valinta("verkko_id", $verkko_id, "verkko", "id", "verkko",
	      "ORDER BY verkko");
}

echo "<tr><td>Kutsu:";
if ($readonly) {
  echo "<td>$kutsu\n";
} else {
  echo "<td><input type=\"text\" name=\"kutsu\" size=64 maxlength=64";
  echo " value=\"$kutsu\">\n";
}

echo "<tr><td>Puhelin:";
if ($readonly) {
  echo "<td>$puhelin\n";
} else {
  echo "<td><input type=\"text\" name=\"puhelin\" size=32 maxlength=32";
  echo " value=\"$puhelin\">\n";
}

echo "<tr><td>Selite:";
if ($readonly) {
  echo "<td>$selite\n";
} else {
  echo "<td><input type=\"text\" name=\"selite\" size=64 maxlength=132";
  echo " value=\"$selite\">\n";
}

echo "<tr><td>Tehtv:";
if ($readonly) {
  echo "<td>$tehtava\n";
} else {
  echo "<td><input type=\"text\" name=\"tehtava\" size=64 maxlength=128";
  echo " value=\"$tehtava\">\n";
}

echo "<tr><td>Toiminta-alue:";
if ($readonly) {
  echo "<td>$toiminta_alue\n";
} else {
  echo "<td><input type=\"text\" name=\"toiminta_alue\" size=64 maxlength=128";
  echo " value=\"$toiminta_alue\">\n";
}

echo "<tr><td>Toimintakanava:";
if ($readonly) {
  echo "<td>$toimintakanava\n";
} else {
  echo "<td><input type=\"text\" name=\"toimintakanava\" size=32 maxlength=32";
  echo " value=\"$toimintakanava\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo
      "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql = "
SELECT ryhma.id,paikka,koordinaatit,ryhma_tila,pri,verkko,kutsu,puhelin,
       ryhma.selite,ryhma.tehtava,ryhma.toiminta_alue,
       ryhma.toimintakanava,ryhma.ts
FROM ryhma,paikka,ryhma_tila,verkko
WHERE ryhma_tila_id = ryhma_tila.id AND paikka_id = paikka.id
      AND verkko_id = verkko.id
ORDER BY pri
";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
    . "<TH>Id<TH>Aikaleima<TH>Sijainti [K]<TH>Tila<TH>Pri<TH>Verkko"
    . "<TH>Kutsu<TH>Puhelin<TH>Selite<TH>Teht<TH>T.alue<TH>Kan\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (visible_operation_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo "<TR><TD>$a[id]",
      "<TD>$a[ts]",
      "<TD>$a[paikka]", muotoile_koordinaatit($a['koordinaatit']),
      "<TD>$a[ryhma_tila]",
      "<TD>$a[pri]",
      "<TD>$a[verkko]",
      "<TD>$a[kutsu]",
      "<TD>$a[puhelin]",
      "<TD>$a[selite]",
      "<TD>" . substr($a['tehtava'], 0, 4),
      "<TD>" . substr($a['toiminta_alue'], 0, 6),
      "<TD>" . substr($a['toimintakanava'], 0, 3);
    if (($id == "0") && ($a['id'] != "1")) {
      echo "<td><a href=\"$table.php?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$table.php?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
} else {
  echo "<P>Plop. Ei ryhmtietoja.";
}

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: ryhma.php,v 1.23 2009/06/06 14:21:57 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/ryhma.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "ryhma";
$file = basename(__FILE__);

include "common.php";
include "ryhma-ok.php";

echo "
<html>
<head>
 <title>VIHA - Ryhmtiedot</title>
</head>
" . body_bgcolor() . "
<h1>" . muotoile_operaatio() . ", ryhmkohtaisten tietojen ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$paikka_id = get_nro_1('paikka_id');
$koordinaatit = get_txt('koordinaatit');
$ryhma_tila_id = get_nro_1('ryhma_tila_id');
$verkko_id = get_nro('verkko_id');
if ($verkko_id == "") { $verkko_id = ota_oletus_verkko_id(); }
$pri = get_nro_0('pri');
$kutsu = get_txt('kutsu');
$puhelin = get_txt('puhelin');
$selite = get_txt('selite');
$tehtava = get_txt('tehtava');
$toiminta_alue = get_txt('toiminta_alue');
$toimintakanava = get_txt('toimintakanava');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = ryhma_add_ok($herja,s('alue'),
		      s('paivystys'),
		      $paikka_id,$ryhma_tila_id,$verkko_id,$kutsu);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    if ($pri == 0)
      $pri = oletus_pri($kutsu);
    $sql =
      "INSERT INTO $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           paikka_id = $paikka_id,
           koordinaatit = '$koordinaatit',
           ryhma_tila_id = $ryhma_tila_id,
           pri = $pri,
           verkko_id = $verkko_id,
           kutsu = '$kutsu',
           puhelin = '$puhelin',
           selite = '$selite',
           tehtava = '$tehtava',
           toiminta_alue = '$toiminta_alue',
           toimintakanava = '$toimintakanava',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
    $msg = "Listty ryhm $kutsu verkkoon " . ota_verkko($verkko_id)
      . ", sijainti " . ota_paikka($paikka_id)
      . ", tila " . ota_ryhma_tila($ryhma_tila_id)
      . ", selite $selite";
    taktinen_loki($msg);
    tehty($msg);
  }
  p_herja($ret,$herja);
}

if (($save != '') && saa_tehda("$file:save")) {
  $ret = ryhma_save_ok($herja,$id,s('alue'),
		       s('paivystys'),
		       $paikka_id,$ryhma_tila_id,$verkko_id,$kutsu);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    if ($pri == 0)
      $pri = oletus_pri($kutsu);
    $sql =
      "UPDATE $table
       SET paikka_id=$paikka_id,
           koordinaatit='$koordinaatit',
           ryhma_tila_id=$ryhma_tila_id,
           pri=$pri,
           verkko_id=$verkko_id,
           kutsu='$kutsu',
           puhelin='$puhelin',
           selite='$selite',
           tehtava = '$tehtava',
           toiminta_alue = '$toiminta_alue',
           toimintakanava = '$toimintakanava',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    loki($sql);
    $msg = "Muutettu ryhm $kutsu, sijainti " . ota_paikka($paikka_id)
      . ", tila " . ota_ryhma_tila($ryhma_tila_id);
    taktinen_loki($msg);
    tehty($msg);
  }
  p_herja($ret,$herja);
} # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = ryhma_remove_ok($herja,$id,true);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $tmp_nimi = ota_kutsu($id);
    taktinen_loki("Poistetaan ryhm $tmp_nimi");
    $sql = "DELETE FROM $table WHERE id = $id";
    my_mysql_query ($sql,true,true);
    # silently update the man-hour table as well
    $sql =
      "UPDATE hlo_ajat
       SET variable_id = 1
       WHERE variable_id = $id AND hlo_ajat_tyyppi_id = 5";
    my_mysql_query ($sql,true,true);
    tehty("Poistettu ryhm $tmp_nimi");
    $clear = "SISINEN";
  }
  p_herja($ret,$herja);
}

if ($clear != '') {
  $id = "0";
  $paikka_id = "1";
  $koordinaatit = '';
  $ryhma_tila_id = "1";
  $verkko_id = ota_oletus_verkko_id();
  $kutsu = '';
  $pri = "0";
  $puhelin = '';
  $selite = '';
  $tehtava = '';
  $toiminta_alue = '';
  $toimintakanava = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = ryhma_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
}

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $paikka_id = $a['paikka_id'];
  $koordinaatit = $a['koordinaatit'];
  $ryhma_tila_id = $a['ryhma_tila_id'];
  $pri = $a['pri'];
  $verkko_id = $a['verkko_id'];
  $kutsu = $a['kutsu'];
  $puhelin = $a['puhelin'];
  $selite = $a['selite']; 
  $tehtava = $a['tehtava']; 
  $toiminta_alue = $a['toiminta_alue']; 
  $toimintakanava = $a['toimintakanava']; 
 }

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Sijainti:";
if ($readonly) {
  echo "<td>" . tab_col_id("paikka","",$paikka_id);
} else {
  echo "<td>\n";
  select_paikka_id($paikka_id);
}

echo "<tr><td>Koordinaatit:";
if ($readonly) {
  echo "<td>$koordinaatit\n";
} else {
  echo "<td><input type=\"text\" name=\"koordinaatit\" size=32 maxlength=32";
  echo " value=\"$koordinaatti\">\n";
  echo " Kartasta, muodossa X99\n";
}

echo "<tr><td>Tila:";
if ($readonly) {
  echo "<td>" . tab_col_id("ryhma_tila","",$ryhma_tila_id);
} else {
  echo "<td>\n";
  select_ryhma_tila_id($ryhma_tila_id);
}

echo "<tr><td>Prioriteetti:";
if ($readonly) {
  echo "<td>$pri\n";
} else {
  echo "<td><input type=\"text\" name=\"pri\" size=8 maxlength=8";
  echo " value=\"$pri\">\n";
  echo " Listauksia varten, pienempi prioriteetti listataan ensin.\n";
}

echo "<tr><td>Verkko:";
if ($readonly) {
  echo "<td>"
    . etsi_teksti("verkko_id", $verkko_id, "verkko", "id", "verkko") . "\n";
} else {
  echo "<td>\n";
  tee_valinta("verkko_id", $verkko_id, "verkko", "id", "verkko",
	      "ORDER BY verkko");
}

echo "<tr><td>Kutsu:";
if ($readonly) {
  echo "<td>$kutsu\n";
} else {
  echo "<td><input type=\"text\" name=\"kutsu\" size=64 maxlength=64";
  echo " value=\"$kutsu\">\n";
}

echo "<tr><td>Puhelin:";
if ($readonly) {
  echo "<td>$puhelin\n";
} else {
  echo "<td><input type=\"text\" name=\"puhelin\" size=32 maxlength=32";
  echo " value=\"$puhelin\">\n";
}

echo "<tr><td>Selite:";
if ($readonly) {
  echo "<td>$selite\n";
} else {
  echo "<td><input type=\"text\" name=\"selite\" size=64 maxlength=132";
  echo " value=\"$selite\">\n";
}

echo "<tr><td>Tehtv:";
if ($readonly) {
  echo "<td>$tehtava\n";
} else {
  echo "<td><input type=\"text\" name=\"tehtava\" size=64 maxlength=128";
  echo " value=\"$tehtava\">\n";
}

echo "<tr><td>Toiminta-alue:";
if ($readonly) {
  echo "<td>$toiminta_alue\n";
} else {
  echo "<td><input type=\"text\" name=\"toiminta_alue\" size=64 maxlength=128";
  echo " value=\"$toiminta_alue\">\n";
}

echo "<tr><td>Toimintakanava:";
if ($readonly) {
  echo "<td>$toimintakanava\n";
} else {
  echo "<td><input type=\"text\" name=\"toimintakanava\" size=32 maxlength=32";
  echo " value=\"$toimintakanava\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo
      "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql = "
SELECT ryhma.id,paikka,koordinaatit,ryhma_tila,pri,verkko,kutsu,puhelin,
       ryhma.selite,ryhma.tehtava,ryhma.toiminta_alue,
       ryhma.toimintakanava,ryhma.ts
FROM ryhma,paikka,ryhma_tila,verkko
WHERE ryhma_tila_id = ryhma_tila.id AND paikka_id = paikka.id
      AND verkko_id = verkko.id
ORDER BY pri
";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<TH>Id<TH>Aikaleima<TH>Sijainti [K]<TH>Tila<TH>Pri<TH>Verkko"
    . "<TH>Kutsu<TH>Puhelin<TH>Selite<TH>Teht<TH>T.alue<TH>Kan\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (visible_operation_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo tr() . "<TD>$a[id]",
      "<TD>$a[ts]",
      "<TD>$a[paikka]", muotoile_koordinaatit($a['koordinaatit']),
      "<TD>$a[ryhma_tila]",
      "<TD>$a[pri]",
      "<TD>$a[verkko]",
      "<TD>$a[kutsu]",
      "<TD>$a[puhelin]",
      "<TD>$a[selite]",
      "<TD>" . substr($a['tehtava'], 0, 4),
      "<TD>" . substr($a['toiminta_alue'], 0, 6),
      "<TD>" . substr($a['toimintakanava'], 0, 3);
    if (($id == "0") && ($a['id'] != "1")) {
      echo "<td><a href=\"$table.php?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$table.php?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
} else {
  echo "<P>Plop. Ei ryhmtietoja.";
}

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: ryhma.php,v 1.28 2009/10/03 15:15:07 riku Exp $ -->
